# coding=utf-8
# *** WARNING: this file was generated by pulumigen. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .CustomResource import *
from .CustomResourcePatch import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_kubernetes.apiextensions.v1 as __v1
    v1 = __v1
    import pulumi_kubernetes.apiextensions.v1beta1 as __v1beta1
    v1beta1 = __v1beta1
else:
    v1 = _utilities.lazy_import('pulumi_kubernetes.apiextensions.v1')
    v1beta1 = _utilities.lazy_import('pulumi_kubernetes.apiextensions.v1beta1')

